<?php

namespace App\Exports;

use Illuminate\Support\Collection;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\WithHeadings;

class SalesOrderExport implements FromCollection, WithHeadings
{
    protected $orders;

    /**
     * Constructor to accept the filtered orders.
     */
    public function __construct(Collection $orders)
    {
        $this->orders = $orders;
    }

    /**
     * @return \Illuminate\Support\Collection
     */
    public function collection()
    {
        if ($this->orders->isEmpty()) {
            return collect([
                ['No records found for the applied filters.']
            ]);
        }
        return $this->orders->map(function ($order, $index) {
            return [
                'Serial Number' => $index + 1,
                'Order Date' => $order->created_at->format('d/m/Y'),
                'Customer Name' => $order->customer_name ?? 'N/A',
                'Number of Products' => $order->total_product,
                'Total Amount' => $order->total_amount,
                'Tax Amount' => $order->tax,
                'Grand Total' => $order->grand_total,
            ];
        });
    }
    public function headings(): array
    {

        return [
            'SL Number',
            'Order Date',
            'Customer Name',
            'Number of Products',
            'Total Amount',
            'Tax Amount',
            'Grand Total',
        ];
    }
}
