<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Brands;
use App\Exports\BrandExport;
use Maatwebsite\Excel\Facades\Excel;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;


class BrandController extends Controller
{
  public function model()
  {
    return new Brands();
  }

  public function index(Request $request)
  {
    $searchColumns = ['id', 'name', 'description'];
    $search = request()->search;
    $order = request()->orderedColumn;
    $orderBy = request()->orderBy;
    $paginate = request()->paginate;

    $query = $this->model()->query();

    if ($search != '')
      $query->where(function ($q) use ($search, $searchColumns) {
        foreach ($searchColumns as $key => $value) ($key == 0) ? $q->where($value, 'LIKE', '%' . $search . '%') : $q->orWhere($value, 'LIKE', '%' . $search . '%');
      });

    ($order == '') ? $query->orderByDesc('id') : $query->orderBy($order, $orderBy);

    $categories = $paginate ? $query->paginate($paginate)->appends(request()->query()) : $query->paginate(10)->appends(request()->query());
    return view('admin.brand.brands', compact('categories'));
  }


  public function addbrands()
  {
    return view('admin.brand.addbrands');
  }

  public function store(Request $request)
  {

    $request->validate([
      'name' => 'required',
      'position' => 'required',
    ]);

    $imagePath='';
    if ($request->hasFile('brand_images')) {
      $folder = 'brand' . $request->id;
      $imagePath = $request->file('brand_images')->store($folder, 'public');
   
    }

    Brands::create([
      'name' => $request->name,
      'position' => $request->position,
      'description' => $request->description,
      'brand_images' => $imagePath,

    ]);
    return redirect()->route('admin.brands')->with('success', 'Brand Added Successfully');
  }

  public function edit(int $id)
  {
    $brands = Brands::findorfail($id);
    return view('admin.brand.editbrands', compact('brands'));
  }
  public function update(Request $request, int $id)
  {
    $request->validate([
      'name' => 'required',
      'position' => 'required',
    ]);

    $brand = Brands::findOrFail($id);

    if ($request->hasFile('brand_images')) {
        if ($brand->brand_images) {
            Storage::disk('public')->delete('brand/'.$brand->brand_images);
        }

        $folder = 'brand/'.$request->id ;
        $imagePath = $request->file('brand_images')->store($folder, 'public');
    } else {
        $imagePath = $brand->brand_images;
    }

    $brand->update([
        'name' => $request->name,
        'position' => $request->position,
        'description' => $request->description,
        'status' => $request->status,
        'brand_images' => $imagePath, 
    ]);

    return redirect()->route('admin.brands')->with('success', 'Brand updated successfully');
}
public function export()
{
  return Excel::download(new BrandExport, 'brands.xlsx');
}
  
  public function destroy($id)
  {
    $deletebrands = Brands::findorfail($id);
    $deletebrands->delete();
    return redirect()->route('admin.brands')->with('success', 'Brands deleted Successfully');
  }
  public function bulkStsChng(Request $request)
  {
    $ids = $request->ids;
    for ($i = 0; $i < count($ids); $i++) {
      $product = Brands::find($ids[$i]);
      $product->update(['status' => $request->status]);
    }
  }

  public function deleteSelected(Request $request)
  {
    Brands::whereIn('id', $request->ids)->delete();
    return response()->json(['message' => 'Brands deleted successfully']);
  }

  public function updateStatus(Request $request, $id)
  {
      $product = Brands::findOrFail($id);
      $product->status = $request->input('status');
      $product->save();
  
      return redirect()->back()->with('success', 'brand  status updated successfully.');
  }
}
