<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Customer;
use Exception;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Hash;
use App\Exports\CustomerExport;
use App\Imports\CustomerImport;
use App\Mail\AccountActivatedMail;
use Illuminate\Support\Facades\Mail;
use Maatwebsite\Excel\Facades\Excel;
use ZipArchive;

class CustomerController extends Controller
{
    public function model()
    {
        return new Customer;
    }
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $searchColumns = ['id', 'customer_id', 'company_name', 'contact_person'];
        $search = request()->search;
        $order = request()->orderedColumn;
        $orderBy = request()->orderBy;
        $paginate = request()->paginate;

        $query = $this->model()->newQuery();

        if ($search != '') {
            $query->where(function ($q) use ($search, $searchColumns) {
                foreach ($searchColumns as $key => $value) {
                    ($key == 0) ? $q->where($value, 'LIKE', '%' . $search . '%') : $q->orWhere($value, 'LIKE', '%' . $search . '%');
                }
            });
        }

        ($order == '') ? $query->orderByDesc('id') : $query->orderBy($order, $orderBy);


        $customers = $paginate ? $query->paginate($paginate)->appends(request()->query()) : $query->paginate(10)->appends(request()->query());

        return view('admin.customer.index', compact('customers'));
    }
    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        $lastCustomer = Customer::orderBy('customer_id', 'desc')->first();
        if ($lastCustomer) {
            $lastCustomerId = $lastCustomer->customer_id;
            $lastCustomerNumber = (int)substr($lastCustomerId, 5);
            $newCustomerNumber = $lastCustomerNumber + 1;
            $newCustomerId = 'VERSC' . str_pad($newCustomerNumber, 4, '0', STR_PAD_LEFT);
        } else {
            $newCustomerId = 'VERSC0001';
        }

        return view('admin.customer.create', compact('newCustomerId'));
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $request->validate([
            'customer_id' => 'required',
            'contact_person' => 'required',
            'phone' => 'required',
            'email' => 'required|unique:customers',
            'shipping_address' => 'required',
            'billing_address' => 'required',
            'password' => 'required',
            'conf_password' => 'required|same:password',
        ]);
        DB::beginTransaction();
        try {
            $data = $request->all();
            $data['password'] = Hash::make($request->password);
            // dd($data);
            $this->model()->create($data);
            DB::commit();
        } catch (Exception $e) {
            DB::rollBack();
            dd($e);
        }
        return redirect()->route('admin.customers')->with('success', 'Customer added successfully');
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $customer = $this->model()->find($id);
        return view('admin.customer.update', compact('customer'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $request->validate([
            'customer_id' => 'required',
            'contact_person' => 'required',
            'phone' => 'required',
            'email' => 'required',
            'billing_address' => 'required',
            'shipping_address' => 'required',
            'conf_password' => 'same:password',
        ]);
        $customer = $this->model()->find($id);
        DB::beginTransaction();
        try {
            $data = $request->all();
            if ($request->password) {
                $data['password'] = Hash::make($request->password);
            } else {
                $data['password'] = $customer->password;
            }
            $customer->update($data);
            DB::commit();
        } catch (Exception $e) {
            DB::rollBack();
            dd($e);
        }
        return redirect()->route('admin.customers')->with('success', 'Customer updated successfully');
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $this->model()->destroy($id);
        return back()->with('success', 'Customer deleted successfully');
    }
    public function export()
    {
        return Excel::download(new CustomerExport, 'customers.xlsx');
    }

    public function bulkStsChng(Request $request)
    {
        $ids = $request->ids;
        for ($i = 0; $i < count($ids); $i++) {
            $product = Customer::find($ids[$i]);
            $product->update(['status' => $request->status]);
        }
    }

    public function deleteSelected(Request $request)
    {
        Customer::whereIn('id', $request->ids)->delete();
        return response()->json(['message' => 'customers deleted successfully']);
    }

    public function updateStatus(Request $request, $id)
    {
        $customer = Customer::findOrFail($id);

        if ($customer->status == false && $request->input('status') == true) {
            $customer->status = true;
            $customer->save();

            Mail::to($customer->email)->send(new AccountActivatedMail($customer));

            return redirect()->back()->with('success', 'Customer status updated and activation email sent.');
        }

        $customer->status = $request->input('status');
        $customer->save();

        return redirect()->back()->with('success', 'Customer status updated successfully.');
    }
    public function bulkUploadView()
    {
        return view('admin.customer.bulk-upload');
    }

    public function bulkUpload(Request $request)
    {
        $request->validate([
            'excel' => 'required|mimes:xls,xlsx',
        ]);

        $file = $request->excel;
        $import = new CustomerImport();
        Excel::import($import, $file);
        $error = '';
        foreach ($import->failures() as $failure) {
            $failure->row();
            $failure->attribute();
            $failure->errors();
            $failure->values();
            $error .= 'Row no:-' . $failure->row() . ', Column:-' . $failure->attribute() . ', Error:-' . $failure->errors()[0] . '<br>';
        }
        return redirect()->route('admin.customers')->with(['success' => 'customers added successfully', 'error_msg' => $error]);
    }
}
