<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Page;
use Illuminate\Http\Request;
use illuminate\Support\Str;

class PageController extends Controller
{
    public function index()
    {
        $page = Page::paginate(10);
        return view('admin.cms.pages.index', compact('page'));
    }
    public function create()
    {
        return view('admin.cms.pages.create');
    }
    public function store(Request $request)
    {
        $request->validate([
            'name' => 'required',
            'position' => 'required',
            'title' => 'required',
            'meta_title' => 'required',
            'meta_description' => 'required',
            'keywords' => 'required',
        ]);
        Page::create([
            'name' => $request->name,
            'position' => $request->position,
            'slug' => Str::slug($request->name),
            'title' => $request->title,
            'description' => $request->description,
            'meta_title' => $request->meta_title,
            'meta_description' => $request->meta_description,
            'meta_keywords' => $request->keywords,
        ]);
        return redirect()->route('admin.pages')->with('message', 'Pages added successfully');
    }
    public function edit(string $id)
    {
        $page = Page::find($id);
        return view('admin.cms.pages.update', compact('page'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $page = Page::find($id);
        $page->update([
            'name' => $request->name,
            'position' => $request->position,
            'slug' => Str::slug($request->name),
            'title' => $request->title,
            'description' => $request->description,
            'meta_title' => $request->meta_title,
            'meta_description' => $request->meta_description,
            'meta_keywords' => $request->keywords,
        ]);
        return redirect()->route('admin.pages')->with('message', 'Pages updated successfully');
    }

    public function destroy(string $id)
    {
        Page::destroy($id);
        return back()->with('message', 'Page removed successfully');
    }
}
