<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Sliders;
use Exception;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Storage;

class SliderController extends Controller
{
    public function model()
    {
        return new Sliders;
    }
    public function index()
    {
        $searchColumns = ['id', 'name', 'position'];
        $search = request()->search;
        $from_date = request()->from_date;
        $to_date = request()->to_date;
        $order = request()->orderedColumn;
        $orderBy = request()->orderBy;
        $paginate = request()->paginate;

        $query = $this->model()->query();

        if ($from_date && $to_date) {
            $query->whereBetween('created_at', [$from_date, $to_date]);
        }
        if ($search != '')
            $query->where(function ($q) use ($search, $searchColumns) {
                foreach ($searchColumns as $key => $value) ($key == 0) ? $q->where($value, 'LIKE', '%' . $search . '%') : $q->orWhere($value, 'LIKE', '%' . $search . '%');
            });

        // sorting
        ($order == '') ? $query->orderByDesc('id') : $query->orderBy($order, $orderBy);

        $sliders = $paginate ? $query->paginate($paginate)->appends(request()->query()) : $query->paginate(10)->appends(request()->query());
        return view('admin.cms.sliders.index', compact('sliders'));
    }

    public function create()
    {
        return view('admin.cms.sliders.create');
    }

    public function bulk(Request $request)
    {
        $type = $request->type;
        $selectedItems = $request->selectedIds;
        $status = $request->status;

        foreach ($selectedItems as $item) {
            $category = Sliders::find($item);
            if ($type == 1) {
                $category->delete();
            } else if ($type == 2) {
                $category->update(['status' => $status]);
            }
        }
        return response()->json(['success' => true, 'message' => 'Bulk operation is completed']);
    }

    public function store(Request $request)
    {
        $request->validate([
            'name' => 'required',
            'position' => 'required',
            'image_url' => 'nullable|image|mimes:jpeg,jpg,png,webp|max:2048',
            'url' => 'required',
        ]);

        DB::beginTransaction();
        try {
            $sliders = Sliders::create([
                'name' => $request->name,
                'position' => $request->position,
                'description' => $request->description,
                'url' => $request->url,
                'status'=>$request->status,
                'image_url' => '',
            ]);

            $imagePath = '';

            if ($request->hasFile('image_url')) {
                $folder = 'sliders/' . $sliders->id;
                $imagePath = $request->file('image_url')->store($folder, 'public');

                $sliders->update(['image_url' => $imagePath]);
            }

            DB::commit();
        } catch (Exception $e) {
            DB::rollBack();
            dd($e);
        }

        return redirect()->route('admin.sliders')->with('success', 'sliders added successfully');
    }

    public function edit(string $id)
    {
        $sliders = Sliders::find($id);
        $slider = Sliders::where('status', 1);
        return view('admin.cms.sliders.update', compact('sliders', 'slider'));
    }
    public function update(Request $request, $id)
    {
        $request->validate([
            'name' => 'required',
            'position' => 'required',
            'image_url' => 'nullable|image|mimes:jpeg,jpg,png,webp|max:2048',
        ]);

        DB::beginTransaction();
        try {
            $sliders = Sliders::findOrFail($id);

            $sliders->update([
                'name' => $request->name,
                'position' => $request->position,
                'description' => $request->description,
                'url' => $request->url,
            ]);

            if ($request->hasFile('image_url')) {
                if ($sliders->image_url) {
                    Storage::disk('public')->delete('flavors/' . $sliders->image_url);
                }

                $folder = 'sliders/' . $sliders->id;

                $imagePath = $request->file('image_url')->store($folder, 'public');

                $sliders->update(['image_url' => $imagePath]);
            }

            DB::commit();
        } catch (Exception $e) {
            DB::rollBack();
            dd($e);
        }

        return redirect()->route('admin.sliders')->with('success', 'sliders updated successfully');
    }

    public function destroy($id) {
        $sliders=Sliders::findorFail($id);
        $sliders->delete();
        return redirect()->route('admin.sliders')->with('success', 'sliders deleted successfully');
    }
    public function bulkStsChng(Request $request)
    {
      $ids = $request->ids;
      for ($i = 0; $i < count($ids); $i++) {
        $tax = Sliders::find($ids[$i]);
        $tax->update(['status' => $request->status]);
      }
    }
  
    public function deleteSelected(Request $request)
    {
      Sliders::whereIn('id', $request->ids)->delete();
      return response()->json(['message' => 'Sliders deleted successfully']);
    }
}
