<?php

namespace App\Http\Controllers\Admin;
use App\Models\User;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Hash;
use App\Exports\AdminExport;
use Maatwebsite\Excel\Facades\Excel;



class SuperAdminController extends Controller
{
    public function model()
    {
        return new User();
    }
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $searchColumns = ['id', 'name', 'email'];
        $search = request()->search;
        $order = request()->orderedColumn;
        $orderBy = request()->orderBy;
        $paginate = request()->paginate;

        $query = User::query(); //$this->model()->query();
        if ($search != '')
            $query->where(function ($q) use ($search, $searchColumns) {
                foreach ($searchColumns as $key => $value) ($key == 0) ? $q->where($value, 'LIKE', '%' . $search . '%') : $q->orWhere($value, 'LIKE', '%' . $search . '%');
            });

        // sorting
        ($order == '') ? $query->orderByDesc('id') : $query->orderBy($order, $orderBy);

        $superadmin = $paginate ? $query->paginate($paginate)->appends(request()->query()) : $query->paginate(10)->appends(request()->query());
        // $superadmin = $this->model()->paginate(10);
        return view('admin.superadmin.index', compact('superadmin'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('admin.superadmin.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $request->validate([
            'name' => 'required',
            'email' => 'required|email|unique:users',
            'password' => 'required|min:4',
            'confirm_password' => 'required|same:password',
        ]);

        User::create([
            'name' => $request->name,
            'email' => $request->email,
            'password' => Hash::make($request->password)
        ]);
        return redirect()->route('admin.superadmin')->with('message', 'Super Admin created successfully');
    }

    /**
     * Display the specified resource.
     */
    public function show(User $superAdmin)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(int $id)
    {
        $superadmin = $this->model()->find($id);
        return view('admin.superadmin.edit', compact('superadmin'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, int $id)
    {
        $request->validate([
            'name' => 'required',
            'email' => 'required|email|unique:users,email,' . $id,
            'password' => 'min:4|nullable',
            'confirm_password' => 'same:password|nullable',
        ]);
        $superadmin = $this->model()->find($id);
        $superadmin->update([
            'name' => $request->name,
            'email' => $request->email,
            'status' => $request->status,
        ]);


        $request->validate([
            'name' => 'required',
            'email' => 'required|email|unique:users,email,' . $id,
            'password' => 'min:4|nullable',
            'confirm_password' => 'same:password|nullable',
        ]);
        $superadmin = $this->model()->find($id);
        $superadmin->update([
            'name' => $request->name,
            'email' => $request->email,
            'status' => $request->status,
        ]);

        if ($request->filled('password')) {
            $superadmin->password = Hash::make($request->password);
            $superadmin->save();
        }
        return redirect()->route('admin.superadmin')->with('success', 'Super Admin updated successfully');
    }

    public function export()
    {
      return Excel::download(new AdminExport, 'superadmin.xlsx');
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(int $id)
    {
        $superadmin = $this->model()->find($id);
        $superadmin->delete();
        return redirect()->route('admin.superadmin')->with('success', 'Super Admin deleted successfully');
    }
    public function deleteselected(Request $request)
    {
        User::whereIn('id', $request->ids)->delete();
        return response()->json(['success' => 'user deleted Succesfully']);
    }
    public function bulkStsChng(Request $request)
    {
        $ids = $request->ids;
        for ($i = 0; $i < count($ids); $i++) {
            $superadmin = User::find($ids[$i]);
            $superadmin->update(['status' => $request->status]);
        }
    }
    public function updateStatus(Request $request, $id)
    {
        $product = User::findOrFail($id);
        $product->status = $request->input('status');
        $product->save();
    
        return redirect()->back()->with('success', 'Admin  status updated successfully.');
    }
}
