<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Tax;
use Illuminate\Http\Request;

class TaxController extends Controller
{
    public function model()
    {
        return new Tax;
    }
    public function index()
    {
        $searchColumns = ['id', 'title', 'percent'];
        $search = request()->search;
        $order = request()->orderedColumn;
        $orderBy = request()->orderBy;
        $paginate = request()->paginate;
    
        $query = $this->model()->query();
    
        if ($search != '')
          $query->where(function ($q) use ($search, $searchColumns) {
            foreach ($searchColumns as $key => $value) ($key == 0) ? $q->where($value, 'LIKE', '%' . $search . '%') : $q->orWhere($value, 'LIKE', '%' . $search . '%');
          });
    
        ($order == '') ? $query->orderByDesc('id') : $query->orderBy($order, $orderBy);
    
        $tax = $paginate ? $query->paginate($paginate)->appends(request()->query()) : $query->paginate(10)->appends(request()->query());
        return view('admin.cms.tax.index', compact('tax'));
    }
    public function create() {
        return view('admin.cms.tax.create');
    }
    public function store(Request $request)
    {
        $request->validate([
            'title'  => 'required',
            'percent' => 'required',
            'status' => 'required'
        ]);
        $this->model()->create($request->all());
        return to_route('admin.tax')->with('message', 'Tax added successfully');
    }

    public function bulkStsChng(Request $request)
    {
      $ids = $request->ids;
      for ($i = 0; $i < count($ids); $i++) {
        $tax = Tax::find($ids[$i]);
        $tax->update(['status' => $request->status]);
      }
    }
  
    public function deleteSelected(Request $request)
    {
      Tax::whereIn('id', $request->ids)->delete();
      return response()->json(['message' => 'tax deleted successfully']);
    }
    public function edit(string $id)
    {
        $tax = $this->model()->find($id);
        return view('admin.cms.tax.update', compact('tax'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $tax = $this->model()->find($id);
        $tax->update([
            'title'      => $request->title,
            'percent'    => $request->percent,
            'status'     => $request->status,
            'description' => $request->description
        ]);
        return to_route('admin.tax')->with('message','Updated successfully');
    }
    public function delete($id){
        
            $this->model()->destroy($id);
            return back()->with('message', 'Tax removed successfully');
        
    }
}
