<?php

namespace App\Http\Controllers\Sale;

use App\Http\Controllers\Controller;
use App\Models\Customer;
use App\Models\Order;
use App\Models\SalesCustomerRelation;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class CustomerController extends Controller
{
    public function index(Request $request)
    {
        $salesperson = Auth::guard('salesperson')->user();

        $searchName = $request->get('search_name');

        $query = SalesCustomerRelation::with('customers')
            ->where('sales_id', $salesperson->id);

        if ($searchName) {
            $query->whereHas('customers', function ($query) use ($searchName) {
                $query->where('contact_person', 'like', '%' . $searchName . '%');  
            });
        }

        $customerRelations = $query->get();

        return view('sales.pages.customer', compact('customerRelations'));
    }


    public function getCustomerDetails(Request $request)
    {
        $customer = Customer::find($request->c_id);

        if ($customer) {
            return view('sales.pages.partials.customer_details', compact('customer'));
        } else {
            return response()->json(['message' => 'Customer not found'], 404);
        }
    }

    public function getOrderDetails($id)
    {
        $orders = Order::with(['customer', 'items.product'])
            ->where('customer_id', $id)
            ->get();

        if ($orders->isEmpty()) {
            return response()->json(['message' => 'No orders found for this customer'], 404);
        }

        return view('sales.pages.partials.order-details', compact('orders'))->render();
    }
    
}
