<?php

namespace App\Http\Controllers\Sale;

use App\Http\Controllers\Controller;
use App\Models\Customer;
use App\Models\SaleOrder;
use App\Models\SalesCustomerRelation;
use App\Models\SalesPerson;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class LoginController extends Controller
{
    public function index()
    {
        return view('sales.auth.login');
    }

    public function authenticate(Request $request)
    {
        $request->validate([
            'email' => 'required|email',
            'password' => 'required',

        ]);
        $attempt = Auth::guard('salesperson')->attempt(['email' => $request->email, 'password' => $request->password]);
        if ($attempt) {
            $salesperson = Auth::guard('salesperson')->user();
            return redirect()->route('sales.dashboard');
        } else {
            return back()->with('danger', 'Invalid credentials.');
        }
    }
    public function dashboard()
    {
        $salesperson = Auth::guard('salesperson')->user();
    
        $orders = SaleOrder::where('sales_id', $salesperson->id);
        $customers=SalesCustomerRelation::where('sales_id',$salesperson->id);
    
        $totalSalesAmount = $orders->sum('total_amount');
    
        $totalOrdersCount = $orders->count();
    
        $totalOrderProductsCount = $orders->sum('total_product');
    
        $totalCustomersCount = $customers->distinct('customer_id')->count('customer_id');
    
        $currentMonthOrdersCount = $orders->whereMonth('created_at', now()->month)
            ->whereYear('created_at', now()->year)
            ->count();
    
        return view('sales.pages.dashboard', compact(
            'totalSalesAmount',
            'totalOrdersCount',
            'totalOrderProductsCount',
            'totalCustomersCount',
            'currentMonthOrdersCount'
        ));
    }
    
    public function logout()
    {
        Auth::guard('salesperson')->logout();
        return redirect()->route('sales.login');
    }

    public function getCustomers()
    {
        $salesperson = Auth::guard('salesperson')->user();

        $customers = SalesCustomerRelation::with('customers')
            ->where('sales_id', $salesperson->id)
            ->get();

        return response()->json($customers);
    }

    public function storeCustomerInSession(Request $request)
    {
        $customer_id = $request->input('customer_id');
        $customer_name = $request->input('customer_name');

        if ($customer_id) {
            session(['selectedCustomerID' => $customer_id]);
            session(['selectedCustomerName' => $customer_name]);

            return response()->json(['success' => true, 'message' => 'Customer stored in session']);
        }

        return response()->json(['success' => false, 'message' => 'No customer selected']);
    }
}
