<?php

namespace App\Http\Controllers\Sale;

use App\Exports\SalesOrder;
use App\Exports\SalesOrderExport;
use App\Http\Controllers\Controller;
use App\Mail\DiscountUpdated;
use App\Mail\InvoiceMail;
use App\Mail\SalesOrderDiscount;
use App\Models\AdminDetails;
use App\Models\Customer;
use App\Models\ProductInventory;
use App\Models\SaleOrder;
use App\Models\SaleOrderItem;
use App\Models\SalesCart;
use Exception;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Mail;
use Maatwebsite\Excel\Facades\Excel;

class OrderController extends Controller
{
    public function model()
    {
        return new SaleOrder();
    }
    public function index(Request $request)
    {
        $customerId = session('selectedCustomerID');
        $customer = Customer::find($customerId);
      
    
        $query = SaleOrder::where('customer_id', $customerId);
    
        if ($request->has('search_id') && $request->get('search_id') != '') {
            $searchId = $request->get('search_id');
            $query = $query->where('id', 'LIKE', "%{$searchId}%");
        }
    
        $orders = $query->get();

        if (!$customerId) {
            return view('sales.pages.orders',compact('customer','orders'));
        }
    
        if (!$customer) {
            return view('sales.pages.orders',compact('customer','orders'));
        }
    
        if ($orders->isEmpty()) {
            return view('sales.pages.orders', ['noOrdersMessage' => 'No orders found']);
        }
    
        return view('sales.pages.orders', compact('orders', 'customer'));
    }
    
    

    public function placeorder(Request $request)
    {
        DB::beginTransaction();
        try {
            $salesperson = Auth::guard('salesperson')->user();
            $customerId = session('selectedCustomerID');
            $customer = Customer::find($customerId);
            $cart = SalesCart::where('customer_id', $customer->id)->first();
            $grand_total = $cart->grand_total;
            if ($cart->price) {
                $grand_total += $cart->price;
            }

            $total_products = $cart->salescartitems->count();

            $order = SaleOrder::create([
                'customer_id' => $customer->id,
                'sales_id' => $salesperson->id,
                'order_id' => 1,
                'company_name' => $customer->company_name,
                'customer_name' => $customer->contact_person,
                'total_product' => $total_products,
                'total_amount' => $cart->total_amount,
                'tax' => $cart->tax ?? 0,
                'grand_total' => $cart->grand_total,
            ]);

            foreach ($cart->salescartitems as $key => $item) {
                $order->saleitems()->create([
                    'product_id' => $item->product_id,
                    'name' => $item->name,
                    'quantity' => $item->quantity,
                    'sku' => $item->sku,
                    'price' => $item->price,
                    'total_amount' => $item->total_amount,
                    'tax_amount' => $item->tax_amount,
                ]);
                $inventory = ProductInventory::where('product_id', $item->product_id)->first();
                $remaining = $inventory->inventory - $item->quantity;
                $inventory->update(['inventory' => $remaining]);
                $item->delete();
            }

            $cart->delete();
            DB::commit();
            $this->sendInvoice($order);
            return redirect()->route('sales.order.success', $order->id);
        } catch (Exception $ex) {
            DB::rollBack();
            dd($ex);
        }
    }

    public function success($id)
    {
        return view('sales.pages.thankyou', compact('id'));
    }

    public function sendInvoice($order)
    {

        $salesperson = Auth::guard('salesperson')->user();

        if (!empty($salesperson) && !empty($salesperson->email)) {
            Mail::to($salesperson->email)->send(new InvoiceMail($order));
        }
        $customerId = session('selectedCustomerID');
        $customer = Customer::find($customerId);
        if ($customer->email) {
            Mail::to($customer->email)->send(new InvoiceMail($order));
        }

        $adminEmail = AdminDetails::first();

        if (!empty($adminEmail) && !empty($adminEmail->email)) {
            Mail::to($adminEmail->email)->send(new InvoiceMail($order));
        }
    }

    public function getOrderDetails($orderId)
    {
        $customerId = session('selectedCustomerID');
        $customer = Customer::find($customerId);

        $order = SaleOrder::with(['saleitems.saleproduct', 'salecustomer'])->find($orderId);

        if (!$order) {
            return response()->json(['error' => 'Order not found'], 404);
        }

        return view('sales.pages.partials.sale-order-details', compact('order', 'customer'))->render();
    }

    public function reports(Request $request)
    {
        $salesperson = Auth::guard('salesperson')->user();

        $query = SaleOrder::query()->where('sales_id', $salesperson->id);

        if ($request->filled('customer_id')) {
            $query->where('customer_id', $request->customer_id);
        }

        if ($request->filled('from_date') && $request->filled('to_date')) {
            $query->whereBetween('created_at', [$request->from_date, $request->to_date]);
        }

        if ($request->filled('order_id')) {
            $query->where('id', $request->order_id);
        }

        $orders = $query->get();

        if ($request->ajax()) {
            return response()->json(['orders' => $orders]);
        }

        $customer = Customer::all();
        return view('sales.pages.reports', compact('customer', 'orders'));
    }


    public function reportorderdetails($id)
    {
        $order = SaleOrder::with(['saleitems.saleproduct', 'salecustomer'])->find($id);
        $customerId = $order->customer_id;
        $customer = Customer::find($customerId);

        if (!$order) {
            return response()->json(['error' => 'Order not found'], 404);
        }

        return view('sales.pages.partials.sale-order-details', compact('order', 'customer'))->render();
    }

    public function reportexport(Request $request)
    {
        $salesperson = Auth::guard('salesperson')->user();

        $query = SaleOrder::query()->where('sales_id', $salesperson->id);

        if ($request->filled('customer_id')) {
            $query->where('customer_id', $request->customer_id);
        }

        if ($request->filled('from_date') && $request->filled('to_date')) {
            $query->whereBetween('created_at', [$request->from_date, $request->to_date]);
        }

        if ($request->filled('order_idd')) {
            $query->where('id', $request->order_id);
        }

        $orders = $query->get();

        return Excel::download(new SalesOrderExport($orders), 'sales_orders.xlsx');
    }


    public function displayorders()
    {
        $searchColumns = ['id', 'company_name', 'customer_name'];
        $search = request()->search;
        $order = request()->orderedColumn;
        $orderBy = request()->orderBy;
        $paginate = request()->paginate;

        $query = $this->model()->newQuery();

        if ($search != '') {
            $query->where(function ($q) use ($search, $searchColumns) {
                foreach ($searchColumns as $key => $value) {
                    ($key == 0) ? $q->where($value, 'LIKE', '%' . $search . '%') : $q->orWhere($value, 'LIKE', '%' . $search . '%');
                }
            });
        }

        ($order == '') ? $query->orderByDesc('id') : $query->orderBy($order, $orderBy);

        $query->with(['saleitems.saleproduct.images', 'salesperson']);

        $orders = $paginate ? $query->paginate($paginate)->appends(request()->query()) : $query->paginate(10)->appends(request()->query());

        return view('admin.saleorders.index', compact('orders'));
    }


    public function show(string $id)
    {
        $order = $this->model()->find($id);
        return view('admin.saleorders.details', compact('order'));
    }

    public function updateDiscount(Request $request, $orderId)
    {
        $discounts = $request->input('discounts');
        $order = SaleOrder::findOrFail($orderId);

        foreach ($discounts as $itemId => $discount) {
            $orderItem = SaleOrderItem::where('order_id', $orderId)->where('id', $itemId)->firstOrFail();

            $quantity = $orderItem->quantity;
            $totalAmount = $discount * $quantity;

            $orderItem->discount = $discount;
            $orderItem->total_amount = $totalAmount;
            $orderItem->save();
        }

        $order->grand_total = $order->saleitems->sum('total_amount');
        $order->total_amount = $order->saleitems->sum('total_amount');
        $order->save();
        $this->sendDiscountUpdateEmail($order, $discounts);

        return response()->json(['success' => true]);
    }
    protected function sendDiscountUpdateEmail($order, $discounts)
    {
        try {
            Mail::to($order->salecustomer->email)->send(new SalesOrderDiscount($order, $discounts));
        } catch (\Exception $e) {
            dd($e);
        }
    }

    public function export()
    {
        return Excel::download(new SalesOrder, 'Sales_Orders.xlsx');
    }
}
