<?php

namespace App\Http\Controllers\Sale;

use App\Http\Controllers\Controller;
use App\Models\Brands;
use App\Models\Category;
use App\Models\Product;
use Illuminate\Http\Request;

class ProductController extends Controller
{
    public function index(Request $request)
    {
        $top_categories = Category::tree()
            ->with('image', 'products')
            ->whereNull('parent_id')
            ->where('status', true)
            ->orderBy('position', 'asc')
            ->get();
    
        $selectedCategoryId = $request->input('category_id') ?? ($top_categories->first()->id ?? null);
        if (!$selectedCategoryId) {
            abort(404, 'No categories available.');
        }
    
        $query = Product::with('images', 'brand_name')
            ->where('status', true)
            ->whereHas('categories', function ($query) use ($selectedCategoryId) {
                $query->where('category_id', $selectedCategoryId);
            });
    
        if ($request->has('brand') && !empty($request->brand)) {
            $brands = explode(',', $request->brand);
            $query->whereIn('brand', $brands);
        }
    
        if ($request->has('price') && !empty($request->price)) {
            $priceRange = explode('-', $request->price);
            if (count($priceRange) == 2) {
                $query->whereBetween('price', [(float) $priceRange[0], (float) $priceRange[1]]);
            }
        }
    
        $products = $query->paginate(20)->appends($request->all());
    
        return view('sales.pages.products', compact('top_categories', 'products', 'selectedCategoryId'));
    }
    
  
}
