<?php

namespace App\Http\Controllers;

use App\Models\Customer;
use App\Models\SalesPerson;
use Exception;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Hash;

class SalesPersonController extends Controller
{
    public function model()
    {
        return new SalesPerson();
    }
    public function index()
    {
        $searchColumns = ['id', 'name', 'email'];
        $search = request()->search;
        $order = request()->orderedColumn;
        $orderBy = request()->orderBy;
        $paginate = request()->paginate;

        $query = $this->model()->newQuery();

        if ($search != '') {
            $query->where(function ($q) use ($search, $searchColumns) {
                foreach ($searchColumns as $key => $value) {
                    ($key == 0) ? $q->where($value, 'LIKE', '%' . $search . '%') : $q->orWhere($value, 'LIKE', '%' . $search . '%');
                }
            });
        }

        ($order == '') ? $query->orderByDesc('id') : $query->orderBy($order, $orderBy);


        $salesperson = $paginate ? $query->paginate($paginate)->appends(request()->query()) : $query->paginate(10)->appends(request()->query());

        return view('admin.salesperson.index', compact('salesperson'));
    }

    public function create()
    {
        $customer = Customer::all();
        return view('admin.salesperson.create', compact('customer'));
    }
    public function store(Request $request)
    {
        $request->validate([
            'name' => 'required|string|max:255',
            'email' => 'required|email|unique:salespeople,email',
            'phone' => 'required|numeric|digits:10',
            'address' => 'required|string',
            'password' => 'required|same:conf_password',
            'conf_password' => 'required',
        ]);

        DB::beginTransaction();
        try {
            $data = $request->all();
            $data['password'] = Hash::make($request->password);

            $salesperson = SalesPerson::create($data);


            if ($request->has('namecheck')) {
                foreach ($request->namecheck as $customerId) {
                    $customer = DB::table('customers')->where('id', $customerId)->first();

                    if ($customer) {
                        DB::table('salescustomers_relations')->insert([
                            'customer_id' => $customer->id,
                            'sales_id' => $salesperson->id,
                            'customer_name' => $customer->contact_person,
                        ]);
                    }
                }
            }

            DB::commit();
            return redirect()->route('admin.salesperson')->with('success', 'Salesperson and associated customers saved successfully.');
        } catch (Exception $e) {
            DB::rollBack();
            return redirect()->back()->with('error', $e->getMessage());
        }
    }

    public function edit($id)
    {
        $salesperson = SalesPerson::with('salescustomersrelation')->find($id);
        $customers = Customer::all();
        return view('admin.salesperson.update', compact('salesperson', 'customers'));
    }

    public function update(Request $request, $id)
    {
        $request->validate([
            'name' => 'required|string|max:255',
            'email' => 'required',
            'address' => 'required|string',
            'password' => 'nullable|same:conf_password',
            'conf_password' => 'nullable',
        ]);

        DB::beginTransaction();
        try {
            $salesperson = SalesPerson::findOrFail($id);

            $data = $request->only(['name', 'email', 'phone', 'address']);

            if ($request->password) {
                $data['password'] = Hash::make($request->password);
            }

            $salesperson->update($data);

            if ($request->has('namecheck')) {
                DB::table('salescustomers_relations')->where('sales_id', $salesperson->id)->delete();

                foreach ($request->namecheck as $customerId) {
                    $customer = DB::table('customers')->where('id', $customerId)->first();

                    if ($customer) {
                        DB::table('salescustomers_relations')->insert([
                            'customer_id' => $customer->id,
                            'sales_id' => $salesperson->id,
                            'customer_name' => $customer->contact_person,
                        ]);
                    }
                }
            }

            DB::commit();
            return redirect()->route('admin.salesperson')->with('success', 'Salesperson and associated customers updated successfully.');
        } catch (Exception $e) {
            DB::rollBack();
            return redirect()->back()->with('error', $e->getMessage());
        }
    }

    public function destroy($id)
    {
        $salesperson = SalesPerson::findOrFail($id);
        $salesperson->delete();
        return redirect()->route('admin.salesperson')->with('success', 'Salesperson deleted successfully.');
    }
    public function bulkStsChng(Request $request)
    {
        $ids = $request->ids;
        for ($i = 0; $i < count($ids); $i++) {
            $sales = SalesPerson::findorfail($ids[$i]);
            $sales->update(['status' => $request->status]);
        }
    }

    public function deleteSelected(Request $request)
    {
        SalesPerson::whereIn('id', $request->ids)->delete();
        return response()->json(['message' => ' deleted successfully']);
    }

    public function updateStatus(Request $request, $id)
    {
        $product = SalesPerson::findOrFail($id);
        $product->status = $request->input('status');
        $product->save();

        return redirect()->back()->with('success', 'status updated successfully.');
    }
}
