<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class Product extends Model
{
    use HasFactory;
    protected $fillable = [
        'name',
        'sku',
        'slug',
        'upc_barcode',
        'brand',
        'is_new',
        'is_best_seller',
        'small_description',
        'description',
        'price',
        'cost',
        'special_price',
        'special_price_from',
        'special_price_to',
        'status',
        'tax_id',
        'weight',
        'no_of_cases',
        'unit_per_case',
        'quantity_on_hand',
    ];

    protected $with = [
        'images',
    ];

    public function metatag()
    {
        return $this->morphOne(MetaTag::class, 'meta_tagable');
    }
    public function brand_name()
    {
        return $this->belongsTo(Brands::class, 'brand', 'id');
    }


    public function categories()
    {
        return $this->hasMany(ProductCategory::class, 'product_id');
    }

    public function images()
    {
        return $this->hasMany(ProductImage::class, 'product_id');
    }

    public function inventory()
    {
        return $this->hasOne(ProductInventory::class, 'product_id');
    }
    public function getInventory()
    {
        return $this->inventory ? $this->inventory->inventory : 0;
    }

    public function getMetaTags()
    {
        $metatag = $this->metatag ? $this->metatag : null;
        return [
            'title' => $metatag ? $metatag->title : '',
            'description' => $metatag ? $metatag->description : '',
            'keywords' => $metatag ? $metatag->keywords : '',
        ];
    }
    public function tax()
    {
        return $this->hasOne(Tax::class, 'id', 'tax_id');
    }
    
    public function variants()
    {
        return $this->hasMany(ProductVariant::class, 'product_id');
    }
}
