let products = [];

function getQuantity(id) {
    return $(`#quantity-${id}`).val() || 1;
}

function updateQuantity(id, value) {
    $(`#quantity-${id}`).val(value);
}

function getSellingPrice(id) {
    let price = parseFloat($(`#selling-price-${id}`).val());
    return isNaN(price) ? 0 : price;
}

function updateSellingPrice(id, value) {
    $(`#selling-price-${id}`).val(value);
}

function addToLocalStorage() {
    localStorage.setItem("products", JSON.stringify(products));
    console.log("Stored products:", products);
   
}


function getProductsFromLocalStorage() {
    let storedProducts = JSON.parse(localStorage.getItem("products")) || [];
    console.log("Retrieved products:", storedProducts);
    return storedProducts;
}

function deleteLocalStorage() {
    localStorage.clear();
    products = [];
    console.log("Local storage cleared");
}

function updateProducts(product) {
    let index = products.findIndex(p => p.id === product.id);
    if (index > -1) {
        products[index] = product;
    } else {
        products.push(product);
    }
    addToLocalStorage();
}

function restoreProducts() {
    products = getProductsFromLocalStorage();
    console.log("Restored products:", products);
    products.forEach(product => {
        $(`#product_id-${product.id}`).prop("checked", true);
        updateQuantity(product.id, product.qty);
        updateSellingPrice(product.id, product.price);
    });
}

$(document).on("click", ".selectProduct", function () {
    let data = $(this).data("value");
    if (!data || !data.id) return;
    let product = {
        id: data.id,
        qty: getQuantity(data.id),
        price: data.price || getSellingPrice(data.id)
    };
    console.log("Product data:", product);

    let isChecked = $(`#product_id-${product.id}`).prop("checked");

    if (isChecked) {
        console.log("Adding product to list:", product);
        updateProducts(product);
    } else {
        console.log("Removing product from list:", product);
        products = products.filter(p => p.id !== product.id);
        addToLocalStorage();
    }
});

$(document).on("click", ".counter__increment, .counter__decrement", function () {
    let id = $(this).data("id");
    let qty = parseInt(getQuantity(id)) || 0;

    if ($(this).hasClass("counter__increment")) {
        qty++;
    } else {
        qty = Math.max(qty - 1, 1);
    }

    updateQuantity(id, qty);
    updateProducts({ id: id, qty: qty, price: getSellingPrice(id) });
});