<?php

use App\Http\Controllers\Admin\CategoryController;
use App\Http\Controllers\Admin\CustomerController;
use App\Http\Controllers\Admin\AdminDetailsController;
use App\Http\Controllers\Admin\BrandController;
use App\Http\Controllers\Admin\LoginController;
use App\Http\Controllers\Admin\NewsLetterController;
use App\Http\Controllers\Admin\OrderController;
use App\Http\Controllers\Admin\PageController;
use App\Http\Controllers\Admin\ProductController;
use App\Http\Controllers\Admin\SliderController;
use App\Http\Controllers\Sale\LoginController as SaleLoginController;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\Admin\SuperAdminController;
use App\Http\Controllers\Admin\TaxController;
use App\Http\Controllers\Admin\VariantController;
use App\Http\Controllers\Admin\VendorEnquiryController;
use App\Http\Controllers\CartController as ControllersCartController;
use App\Http\Controllers\CustomerPasswordResetController;
use App\Http\Controllers\frontend\ShopController;
use App\Http\Controllers\frontend\CartController;
use App\Http\Controllers\frontend\CheckoutController;
use App\Http\Controllers\frontend\CustomerPasswordResetController as FrontendCustomerPasswordResetController;
use App\Http\Controllers\frontend\EnquiryController;
use App\Http\Controllers\frontend\UserController;
use App\Http\Controllers\Sale\CartController as SaleCartController;
use App\Http\Controllers\Sale\CustomerController as SaleCustomerController;
use App\Http\Controllers\Sale\OrderController as SaleOrderController;
use App\Http\Controllers\Sale\ProductController as SaleProductController;
use App\Http\Controllers\SalesPersonController;

Route::get('/', [ShopController::class, 'index']);
Route::get('products-lists', [ShopController::class, 'productlist'])->name('guest.productlists');
Route::get('brands', [ShopController::class, 'brandlists'])->name('guest.brandlists');
Route::get('categories', [ShopController::class, 'categorylists'])->name('guest.categories');
Route::get('page/{page}', [ShopController::class, 'pageDetails'])->name('page.view');
Route::get('contact-us', [EnquiryController::class, 'contactus'])->name('guest.contact-us');
Route::post('contact-us', [EnquiryController::class, 'store']);
Route::get('vendor-enquiry', [EnquiryController::class, 'getvendor'])->name('guest.vendor');
Route::post('vendor-enquiry', [EnquiryController::class, 'storevendor']);

// news letter
Route::post('new-subscription', [NewsLetterController::class, 'subscription'])->name('new.subscription');


//guest cart
Route::get('cart-items', [CartController::class, 'cartItems'])->name('get-cart-items');
Route::get('cart', [CartController::class, 'cartview'])->name('cart');
Route::post('add/cart', [CartController::class, 'store'])->name('add-to-cart');
Route::get('add/cart/{id}', [CartController::class, 'storeQty1']);
Route::get('cart-item/delete/{id}', [CartController::class, 'destroy'])->name('delete-cart');
Route::post('/cart/update', [CartController::class, 'update'])->name('cart-update');
Route::post('/coupon/apply', [CartController::class, 'applyCoupon'])->name('coupon.apply');
Route::get('/coupon/{id}/remove', [CartController::class, 'removeCoupon'])->name('coupon.remove');

//auth and customer
Route::get('/register', [UserController::class, 'register'])->name('customer.register');
Route::get('/login', [UserController::class, 'login'])->name('customer.login');
Route::post('/register/store', [UserController::class, 'store'])->name('customer.store');
Route::post('/customer/verify', [UserController::class, 'authenticate'])->name('customer.verify');
Route::get('/forget-password', [FrontendCustomerPasswordResetController::class, 'forgetView'])->name('customer.forget.password');
Route::post('/forget-password', [FrontendCustomerPasswordResetController::class, 'forgetMail']);
Route::get('customer/{token}/password-reset', [FrontendCustomerPasswordResetController::class, 'resetView'])->name('customer.reset.view');
Route::post('customer/password-reset', [FrontendCustomerPasswordResetController::class, 'resetPassword'])->name('customer.password.reset');



Route::group(['middleware' => 'auth:customer'], function () {


    Route::get('customer/logout', [UserController::class, 'logout'])->name('customer.logout');
    Route::get('customer/profile', [UserController::class, 'profile'])->name('customer.profile');
    Route::get('customer/checkout', [CheckoutController::class, 'checkout'])->name('customer.checkout');
    Route::post('customer/placeorder', [CheckoutController::class, 'placeorder'])->name('customer.placeorder');
    Route::get('thankyou', [CheckoutController::class, 'success'])->name('order.success');
    Route::post('customer/update/profile', [UserController::class, 'update'])->name('customer.update.profile');
    Route::post('customer/reset/password', [UserController::class, 'reset'])->name('customer.reset.password');
    Route::get('customer/orders', [UserController::class, 'orders'])->name('customer.orders');
    Route::get('customer/order/{id}/details', [UserController::class, 'orderDetails'])->name('customer.order.details');
    Route::get('/order/reorder/{id}', [CheckoutController::class, 'reorder'])->name('order.reorder');
    Route::post('/order/create-new', [CheckoutController::class, 'createNew'])->name('order.create');
});


Route::prefix('admin')->name('admin.')->group(function () {
    Route::get('/', function () {
        return redirect()->route('admin.login');
    });
    Route::get('login', [LoginController::class, 'index'])->name('login');
    Route::post('login', [LoginController::class, 'authenticate']);
    Route::group(['middleware' => 'auth'], function () {
        Route::get('/dashboard', [LoginController::class, 'dashboard'])->name('dashboard');
        Route::post('logout', [LoginController::class, 'logout'])->name('logout');

        // brands
        Route::get('/brands', [BrandController::class, 'index'])->name('brands');
        Route::get('addbrands', [BrandController::class, 'addbrands'])->name('addbrands');
        Route::post('storebrands', [BrandController::class, 'store'])->name('storebrands');
        Route::get('/admin/brands/{id}/edit', [BrandController::class, 'edit'])->name('editbrands');
        Route::put('/admin/brands/{id}/update', [BrandController::class, 'update'])->name('updatebrands');
        Route::get('/admin/brands/{id}/delete', [BrandController::class, 'destroy'])->name('deletebrands');
        Route::post('brands/updateStatus/{id}', [BrandController::class, 'updateStatus'])->name('brands.updateStatus');
        Route::post('brands/delete_selected', [BrandController::class, 'deleteSelected']);
        Route::post('brands/statusChng_selected', [BrandController::class, 'bulkStsChng']);
        Route::get('brands/export', [BrandController::class, 'export'])->name('brand.export');


        // settings
        Route::get('/settings', [AdminDetailsController::class, 'index'])->name('settings');
        Route::put('/admin/settings/update', [AdminDetailsController::class, 'update'])->name('updatedetails');

        // Category
        Route::get('categories', [CategoryController::class, 'index'])->name('categories');
        Route::get('category/create', [CategoryController::class, 'create'])->name('category.create');
        Route::post('category/create', [CategoryController::class, 'store']);
        Route::get('category/{id}/edit', [CategoryController::class, 'edit'])->name('category.edit');
        Route::post('category/{id}/edit', [CategoryController::class, 'update']);
        Route::get('category/{id}/delete', [CategoryController::class, 'destroy'])->name('category.delete');
        Route::post('category/updateStatus/{id}', [CategoryController::class, 'updateStatus'])->name('category.updateStatus');
        Route::post('categories/delete_selected', [CategoryController::class, 'deleteSelected']);
        Route::post('categories/statusChng_selected', [CategoryController::class, 'bulkStsChng']);
        Route::get('category/export', [CategoryController::class, 'export'])->name('category.export');

        // products
        Route::get('products', [ProductController::class, 'index'])->name('products');
        Route::get('product/create', [ProductController::class, 'create'])->name('product.create');
        Route::post('product/create', [ProductController::class, 'store']);
        Route::get('product/{id}/edit', [ProductController::class, 'edit'])->name('product.edit');
        Route::post('product/{id}/edit', [ProductController::class, 'update']);
        Route::get('product/{id}/delete', [ProductController::class, 'destroy'])->name('product.delete');
        Route::get('product_image/{id}/delete', [ProductController::class, 'imageDelete'])->name('product.image.delete');
        Route::post('product/updateStatus/{id}', [ProductController::class, 'updateStatus'])->name('product.updateStatus');
        Route::post('products/delete_selected', [ProductController::class, 'deleteSelected']);
        Route::post('products/statusChng_selected', [ProductController::class, 'bulkStsChng']);
        Route::get('products/export', [ProductController::class, 'export'])->name('product.export');
        Route::post('products/update_name', [ProductController::class, 'updateName']);
        Route::post('products/update_price', [ProductController::class, 'updatePrice']);

        // product bulk upload
        Route::get('product/bulk-upload', [ProductController::class, 'bulkUploadView'])->name('bulkuploads');
        Route::post('product/bulk-upload', [ProductController::class, 'bulkUpload']);

        // orders
        Route::get('orders', [OrderController::class, 'index'])->name('orders');
        Route::get('order/create', [OrderController::class, 'create'])->name('order.create');
        Route::post('order/create', [OrderController::class, 'store']);
        Route::get('order/{id}/details', [OrderController::class, 'show'])->name('order.details');
        Route::get('order/{id}/edit', [OrderController::class, 'edit'])->name('order.edit');
        Route::post('order/{id}/edit', [OrderController::class, 'update']);
        Route::get('order/export', [OrderController::class, 'export'])->name('order.export');
        Route::post('order/{orderId}/update-discount', [OrderController::class, 'updateDiscount'])->name('order.updatediscount');

        //SalesOrder
        Route::get('sales-orders', [SaleOrderController::class, 'displayorders'])->name('salesorders');
        Route::get('sales-order/{id}/details', [SaleOrderController::class, 'show'])->name('salesorders.details');
        Route::post('sales-order/{orderId}/update-discount', [SaleOrderController::class, 'updateDiscount'])->name('salesorders.updatediscount');
        Route::get('sales-order/export', [SaleOrderController::class, 'export'])->name('salesorders.export');



        // customers
        Route::get('customers', [CustomerController::class, 'index'])->name('customers');
        Route::get('customer/create', [CustomerController::class, 'create'])->name('customer.create');
        Route::post('customer/create', [CustomerController::class, 'store']);
        Route::get('customer/{id}/edit', [CustomerController::class, 'edit'])->name('customer.edit');
        Route::post('customer/{id}/edit', [CustomerController::class, 'update']);
        Route::get('customer/{id}/delete', [CustomerController::class, 'destroy'])->name('customer.delete');
        Route::post('customer/updateStatus/{id}', [CustomerController::class, 'updateStatus'])->name('customer.updateStatus');
        Route::post('customers/delete_selected', [CustomerController::class, 'deleteSelected']);
        Route::post('customers/statusChng_selected', [CustomerController::class, 'bulkStsChng']);
        Route::get('customers/export', [CustomerController::class, 'export'])->name('customer.export');

        //customer Bulk Upload
        Route::get('customer/bulk-upload', [CustomerController::class, 'bulkUploadView'])->name('customer.bulkuploads');
        Route::post('customer/bulk-upload', [CustomerController::class, 'bulkUpload']);

        //sales Person
        Route::get('sales-person', [SalesPersonController::class, 'index'])->name('salesperson');
        Route::get('sales-person/create', [SalesPersonController::class, 'create'])->name('salesperson.create');
        Route::post('sales-person/create', [SalesPersonController::class, 'store']);
        Route::get('sales-person/{id}/edit', [SalesPersonController::class, 'edit'])->name('salesperson.edit');
        Route::post('sales-person/{id}/edit', [SalesPersonController::class, 'update']);
        Route::get('sales-person/{id}/delete', [SalesPersonController::class, 'destroy'])->name('salesperson.delete');
        Route::post('sales-person/updateStatus/{id}', [SalesPersonController::class, 'updateStatus'])->name('salesperson.updateStatus');
        Route::post('sales-person/delete_selected', [SalesPersonController::class, 'deleteSelected']);
        Route::post('sales-person/statusChng_selected', [SalesPersonController::class, 'bulkStsChng']);

        // super Admin
        Route::get('superadmin', [SuperAdminController::class, 'index'])->name('superadmin');
        Route::get('superadmin/create', [SuperAdminController::class, 'create'])->name('superadmin.create');
        Route::post('superadmin/create', [SuperAdminController::class, 'store'])->name('superadmin.store');
        Route::get('superadmin/{id}/edit', [SuperAdminController::class, 'edit'])->name('superadmin.edit');
        Route::put('superadmin/{id}/update', [SuperAdminController::class, 'update'])->name('superadmin.update');
        Route::get('superadmin/{id}/delete', [SuperAdminController::class, 'destroy'])->name('superadmin.destroy');
        Route::post('superadmin/updateStatus/{id}', [SuperAdminController::class, 'updateStatus'])->name('superadmin.updateStatus');
        Route::post('superadmin/statusChng_selected', [SuperAdminController::class, 'bulkStsChng']);
        Route::post('superadmin/delete_selected', [SuperAdminController::class, 'deleteselected']);
        Route::get('superadmin/export', [SuperAdminController::class, 'export'])->name('superadmin.export');
    });

    //pages
    Route::get('pages', [PageController::class, 'index'])->name('pages');
    Route::get('page/create', [PageController::class, 'create'])->name('page.create');
    Route::post('page/store', [PageController::class, 'store'])->name('page.store');
    Route::get('page/{id}/edit', [PageController::class, 'edit'])->name('page.edit');
    Route::post('page/{id}/edit', [PageController::class, 'update']);
    Route::get('page/{id}/delete', [PageController::class, 'destroy'])->name('page.delete');

    //Taxes
    Route::get('taxes', [TaxController::class, 'index'])->name('tax');
    ROute::get('taxes/create', [TaxController::class, 'create'])->name('tax.create');
    Route::post('taxes/create', [TaxController::class, 'store'])->name('tax.store');
    Route::get('taxes/edit/{id}', [TaxController::class, 'edit'])->name('tax.edit');
    Route::post('taxes/edit/{id}', [TaxController::class, 'update']);
    Route::get('taxes/delete/{id}', [TaxController::class, 'delete'])->name('tax.delete');
    Route::post('taxes/delete_selected', [TaxController::class, 'deleteSelected']);
    Route::post('taxes/statusChng_selected', [TaxController::class, 'bulkStsChng']);

    //Sliders
    Route::get('sliders', [SliderController::class, 'index'])->name('sliders');
    Route::get('sliders/create', [SliderController::class, 'create'])->name('sliders.create');
    Route::post('sliders/create', [SliderController::class, 'store'])->name('sliders.create');
    Route::get('sliders/{id}/edit', [SliderController::class, 'edit'])->name('sliders.edit');
    Route::post('sliders/{id}/edit', [SliderController::class, 'update']);
    Route::get('sliders/{id}/destroy', [SliderController::class, 'destroy'])->name('sliders.destroy');
    Route::post('sliders/delete_selected', [SliderController::class, 'deleteSelected']);
    Route::post('sliders/statusChng_selected', [SliderController::class, 'bulkStsChng']);

    //variants
    Route::get('variants', [VariantController::class, 'index'])->name('variants');
    Route::get('variants', [VariantController::class, 'index'])->name('variants');
    Route::post('variant', [VariantController::class, 'store'])->name('variant.store');
    Route::get('variant-value', [VariantController::class, 'variantValue'])->name('variant.value.index');
    Route::post('variant-value', [VariantController::class, 'variantValueStore'])->name('variant.value.store');
    Route::get('product_variante/{id}/delete', [ProductController::class, 'varianteDelete'])->name('variante.delete');

    //enquiries
    Route::get('enquiries', [EnquiryController::class, 'index'])->name('enquiries');
    Route::get('enquiry/{id}/delete', [EnquiryController::class, 'destroy'])->name('enquiry.delete');

    //vendorEnquiry
    Route::get('vendorEnquiry', [VendorEnquiryController::class, 'index'])->name('vendorenquiry');
    Route::get('vendorEnquiry/{id}/delete', [VendorEnquiryController::class, 'delete'])->name('vendorenquiry.delete');
    // Newsletter
    Route::get('newsletters', [NewsLetterController::class, 'index'])->name('newsletters');
    Route::get('subscriber/{id}/edit', [NewsLetterController::class, 'edit'])->name('subscriber.edit');
    Route::post('subscriber/{id}/edit', [NewsLetterController::class, 'update']);
    Route::get('subscriber/{id}/delete', [NewsLetterController::class, 'destroy'])->name('subscriber.delete');
    Route::get('subscriber/export', [NewsLetterController::class, 'export'])->name('subscriber.export');
});


Route::prefix('sales')->name('sales.')->group(function () {
    Route::get('/', function () {
        return redirect()->route('sales.login');
    });
    Route::get('login', [SaleLoginController::class, 'index'])->name('login');
    Route::post('login', [SaleLoginController::class, 'authenticate']);
    Route::get('getcustomers', [SaleLoginController::class, 'getCustomers'])->name('getcustomers');
    Route::post('store-customer-session', [SaleLoginController::class, 'storeCustomerInSession'])->name('storeCustomerInSession');


    Route::group(['middleware' => 'auth:salesperson'], function () {

        Route::get('dashboard', [SaleLoginController::class, 'dashboard'])->name('dashboard');
        Route::get('logout', [SaleLoginController::class, 'logout'])->name('logout');
        Route::get('customer', [SaleCustomerController::class, 'index'])->name('customers');
        Route::get('/getCustomerDetails/{c_id}', [SaleCustomerController::class, 'getCustomerDetails'])->name('getCustomerDetails');
        Route::get('getcustomerorder/{customerId}', [SaleCustomerController::class, 'getOrderDetails'])->name('getOrderDetails');
        Route::get('searchcustomer', [SaleCustomerController::class, 'searchcustomer'])->name('searchcustomer');

        //productspage
        Route::get('products', [SaleProductController::class, 'index'])->name('products');

        //salescart
        Route::post('/add/cart', [SaleCartController::class, 'addToCart'])->name('add_to_cart');
        Route::get('carts', [SaleCartController::class, 'index'])->name('carts');
        Route::get('/carts/delete/{id}', [SaleCartController::class, 'deletecart'])->name('cart.delete');
        Route::get('/update-cart-item', [SaleCartController::class, 'updateCartitem'])->name('cart.update');
        Route::get('/get-cart-count', [SaleCartController::class, 'getCartCount'])->name('get.cart.count');

        //orders
        Route::post('placeorder', [SaleOrderController::class, 'placeorder'])->name('placeorder');
        Route::get('orders', [SaleOrderController::class, 'index'])->name('orders');
        Route::get('order/{id}/success', [SaleOrderController::class, 'success'])->name('order.success');
        Route::get('/order/details/{id}', [SaleOrderController::class, 'getOrderDetails'])->name('order.details');

        //reports
        Route::get('reports', [SaleOrderController::class, 'reports'])->name('reports');
        Route::get('reports/order/details/{id}', [SaleOrderController::class, 'reportorderdetails'])->name('order.details');
        Route::post('reports/export', [SaleOrderController::class, 'reportexport'])->name('report.export');
    });
});

Route::post('products/by/category', [CategoryController::class, 'products'])->name('products.by.category');

Route::any('{any}', [ShopController::class, 'productByCategory'])->name('productByCategory');
